==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/d4c/structIndustrySpec.js <==
var structIndustrySpec =
[
    [ "GetConstructionCost", "db/d4c/structIndustrySpec.html#ac43ae395a73504d5fac32ca2c5c658e1", null ],
    [ "GetRemovalCost", "db/d4c/structIndustrySpec.html#a2c6ec95874e89f66c27571136091e4c1", null ],
    [ "IsProcessingIndustry", "db/d4c/structIndustrySpec.html#a11c18476d01aa4fccbf5ba2c473a4b77", null ],
    [ "IsRawIndustry", "db/d4c/structIndustrySpec.html#a6d0820b7c6056963938b692ddc077251", null ],
    [ "UsesSmoothEconomy", "db/d4c/structIndustrySpec.html#ae9112d1adc53e795b218f307fab458a2", null ],
    [ "accepts_cargo", "db/d4c/structIndustrySpec.html#aac895065b958b8ee12ad0ec2459e33a4", null ],
    [ "appear_creation", "db/d4c/structIndustrySpec.html#a38fe4502d964530d8c5f11aa08b628c9", null ],
    [ "appear_ingame", "db/d4c/structIndustrySpec.html#ad8f0ae2aab3a30098d7c2000c31c4df6", null ],
    [ "behaviour", "db/d4c/structIndustrySpec.html#a5ef1d3ea626d45c39971659ce526de90", null ],
    [ "callback_mask", "db/d4c/structIndustrySpec.html#a8893de3c49dac0df9175a33f84f45c18", null ],
    [ "check_proc", "db/d4c/structIndustrySpec.html#a81171c4f20677fc180a5cd99fbff0405", null ],
    [ "cleanup_flag", "db/d4c/structIndustrySpec.html#aa1cb02f6837d610fe11f0ba497c85025", null ],
    [ "climate_availability", "db/d4c/structIndustrySpec.html#a6e3dc3f5b4826ae93100c87011c2b022", null ],
    [ "closure_text", "db/d4c/structIndustrySpec.html#a91370948656344678890f667a789c78c", null ],
    [ "conflicting", "db/d4c/structIndustrySpec.html#a722d3484b185c4e4fa60780c06b1659e", null ],
    [ "cost_multiplier", "db/d4c/structIndustrySpec.html#a963139a674c8504d2f243bdd8e94fa9d", null ],
    [ "enabled", "db/d4c/structIndustrySpec.html#ab0865a1555ba4ab09e53a64c03035682", null ],
    [ "grf_prop", "db/d4c/structIndustrySpec.html#a78da0658e53f0d00f7819f8311ebd138", null ],
    [ "input_cargo_multiplier", "db/d4c/structIndustrySpec.html#af2d829fbceb29d55b7f725d78cac0047", null ],
    [ "life_type", "db/d4c/structIndustrySpec.html#a908dde17c47e41020b3648f342326309", null ],
    [ "map_colour", "db/d4c/structIndustrySpec.html#ae2354e6087446a9097b99186cef24889", null ],
    [ "minimal_cargo", "db/d4c/structIndustrySpec.html#a75898d597e3dc92419da35b0abf46811", null ],
    [ "name", "db/d4c/structIndustrySpec.html#a5029ed9bc3fa39823478e625547c3cc9", null ],
    [ "new_industry_text", "db/d4c/structIndustrySpec.html#aa129f7870817619afc83649495c508d6", null ],
    [ "num_table", "db/d4c/structIndustrySpec.html#a846df1bc1edd61616d1c23afc074d145", null ],
    [ "number_of_sounds", "db/d4c/structIndustrySpec.html#a4ebacfc465dccc6d3e4604b2ab0ad0fa", null ],
    [ "produced_cargo", "db/d4c/structIndustrySpec.html#a0c9d49a89cf4d640e40242384235ef3a", null ],
    [ "production_down_text", "db/d4c/structIndustrySpec.html#a7c1f77828273d30c8aff092683328635", null ],
    [ "production_rate", "db/d4c/structIndustrySpec.html#a07be705ef56b576d82db30c874fa046a", null ],
    [ "production_up_text", "db/d4c/structIndustrySpec.html#a4ab0c1d1ce787b82879bc4257e54fb2f", null ],
    [ "prospecting_chance", "db/d4c/structIndustrySpec.html#ac4fdf93ca2f0263fa94cd9a121b02734", null ],
    [ "random_sounds", "db/d4c/structIndustrySpec.html#a6aba2a7e1c8b7d73382074f76ae13bf3", null ],
    [ "removal_cost_multiplier", "db/d4c/structIndustrySpec.html#a92126da865b7b1cd59daf4248d8c5c91", null ],
    [ "station_name", "db/d4c/structIndustrySpec.html#a86799b16bc2faa4a1169cab4dd126cd1", null ],
    [ "table", "db/d4c/structIndustrySpec.html#a2e121b6fb791f59ab950dca1474de2f3", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/d4c/structIndustrySpec.js <==
var structIndustrySpec =
[
    [ "~IndustrySpec", "db/d4c/structIndustrySpec.html#acefbd4c19889363fc2daedee5fe829d2", null ],
    [ "GetConstructionCost", "db/d4c/structIndustrySpec.html#ac43ae395a73504d5fac32ca2c5c658e1", null ],
    [ "GetRemovalCost", "db/d4c/structIndustrySpec.html#a2c6ec95874e89f66c27571136091e4c1", null ],
    [ "IsProcessingIndustry", "db/d4c/structIndustrySpec.html#a11c18476d01aa4fccbf5ba2c473a4b77", null ],
    [ "IsRawIndustry", "db/d4c/structIndustrySpec.html#a6d0820b7c6056963938b692ddc077251", null ],
    [ "UsesOriginalEconomy", "db/d4c/structIndustrySpec.html#a38bc385c073db085661e7e4a056ac3e7", null ],
    [ "accepts_cargo", "db/d4c/structIndustrySpec.html#aac895065b958b8ee12ad0ec2459e33a4", null ],
    [ "appear_creation", "db/d4c/structIndustrySpec.html#a38fe4502d964530d8c5f11aa08b628c9", null ],
    [ "appear_ingame", "db/d4c/structIndustrySpec.html#ad8f0ae2aab3a30098d7c2000c31c4df6", null ],
    [ "behaviour", "db/d4c/structIndustrySpec.html#a5ef1d3ea626d45c39971659ce526de90", null ],
    [ "callback_mask", "db/d4c/structIndustrySpec.html#a8893de3c49dac0df9175a33f84f45c18", null ],
    [ "check_proc", "db/d4c/structIndustrySpec.html#a81171c4f20677fc180a5cd99fbff0405", null ],
    [ "cleanup_flag", "db/d4c/structIndustrySpec.html#aa1cb02f6837d610fe11f0ba497c85025", null ],
    [ "climate_availability", "db/d4c/structIndustrySpec.html#a6e3dc3f5b4826ae93100c87011c2b022", null ],
    [ "closure_text", "db/d4c/structIndustrySpec.html#a91370948656344678890f667a789c78c", null ],
    [ "conflicting", "db/d4c/structIndustrySpec.html#a722d3484b185c4e4fa60780c06b1659e", null ],
    [ "cost_multiplier", "db/d4c/structIndustrySpec.html#a963139a674c8504d2f243bdd8e94fa9d", null ],
    [ "enabled", "db/d4c/structIndustrySpec.html#ab0865a1555ba4ab09e53a64c03035682", null ],
    [ "grf_prop", "db/d4c/structIndustrySpec.html#a78da0658e53f0d00f7819f8311ebd138", null ],
    [ "input_cargo_multiplier", "db/d4c/structIndustrySpec.html#af2d829fbceb29d55b7f725d78cac0047", null ],
    [ "layouts", "db/d4c/structIndustrySpec.html#aae746895f86f39be1c3d0d18d2abf786", null ],
    [ "life_type", "db/d4c/structIndustrySpec.html#a908dde17c47e41020b3648f342326309", null ],
    [ "map_colour", "db/d4c/structIndustrySpec.html#ae2354e6087446a9097b99186cef24889", null ],
    [ "minimal_cargo", "db/d4c/structIndustrySpec.html#a75898d597e3dc92419da35b0abf46811", null ],
    [ "name", "db/d4c/structIndustrySpec.html#a5029ed9bc3fa39823478e625547c3cc9", null ],
    [ "new_industry_text", "db/d4c/structIndustrySpec.html#aa129f7870817619afc83649495c508d6", null ],
    [ "number_of_sounds", "db/d4c/structIndustrySpec.html#a4ebacfc465dccc6d3e4604b2ab0ad0fa", null ],
    [ "produced_cargo", "db/d4c/structIndustrySpec.html#a0c9d49a89cf4d640e40242384235ef3a", null ],
    [ "production_down_text", "db/d4c/structIndustrySpec.html#a7c1f77828273d30c8aff092683328635", null ],
    [ "production_rate", "db/d4c/structIndustrySpec.html#a07be705ef56b576d82db30c874fa046a", null ],
    [ "production_up_text", "db/d4c/structIndustrySpec.html#a4ab0c1d1ce787b82879bc4257e54fb2f", null ],
    [ "prospecting_chance", "db/d4c/structIndustrySpec.html#ac4fdf93ca2f0263fa94cd9a121b02734", null ],
    [ "random_sounds", "db/d4c/structIndustrySpec.html#a6aba2a7e1c8b7d73382074f76ae13bf3", null ],
    [ "removal_cost_multiplier", "db/d4c/structIndustrySpec.html#a92126da865b7b1cd59daf4248d8c5c91", null ],
    [ "station_name", "db/d4c/structIndustrySpec.html#a86799b16bc2faa4a1169cab4dd126cd1", null ]
];
